﻿using System;
using System.IO;
using Xamarin.Forms;
using Notes.Models;
using Syncfusion.XForms.RichTextEditor;

namespace Notes
{
    public partial class NoteEntryPage : ContentPage
    {
        private SfRichTextEditor RichTextEditor;
        public NoteEntryPage()
        {
            InitializeComponent();

            RichTextEditor = new SfRichTextEditor()
            {
                VerticalOptions = LayoutOptions.FillAndExpand,
                PlaceHolder = "Write your notes here!",
            };

            if (BindingContext != null)
            {
                Note note = BindingContext as Note;
                RichTextEditor.HtmlText = note.Text;
            }

            RichTextEditor.SetBinding(SfRichTextEditor.HtmlTextProperty, "HTMLText");

            StackLayout.Children.Add(RichTextEditor);
        }

        async void OnSaveButtonClicked(object sender, EventArgs e)
        {
            var note = (Note)BindingContext;

            if (string.IsNullOrWhiteSpace(note.Filename))
            {
                // Save
                var filename = Path.Combine(App.FolderPath, $"{Path.GetRandomFileName()}.notes.txt");
                File.WriteAllText(filename, RichTextEditor.HtmlText);
            }
            else
            {
                // Update 
                File.WriteAllText(note.Filename, RichTextEditor.HtmlText);
            }

            await Navigation.PopAsync();
        }

        async void OnDeleteButtonClicked(object sender, EventArgs e)
        {
            var note = (Note)BindingContext;

            if (File.Exists(note.Filename))
            {
                File.Delete(note.Filename);
            }

            await Navigation.PopAsync();
        }
    }
}
